{% extends "base.html" %}

{% block title %}
    <title>Document not found</title>
{% endblock %}


{% block content %}

    <div class="page-header">
        <h1 class="display-4">404 </h1>
        <p class="lead">The document you requested is not here.</p>
    </div>

{% endblock %}

{% block script %}
<script type="text/javascript">



</script>
{% endblock %}
