{% extends "document.html" %}



{% block head %}

<style type="text/css">
    .page-header {
        background-color: #400e0e7d;
        color:white;
    }
    .page-main {
        background-color: black;
        background: url(https://i.imgur.com/lXkeFGo.gif);
        background-size: 100%;
        font-family: monospace;
        color: green!important;
    }
</style>

{% endblock %}
